#ifndef NT2_INCLUDE_FUNCTIONS_ATAND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ATAND_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/atand.hpp>

#endif
